@@ -123,7 +123,7 @@ if (isset($_POST["action"])) {
             break;
         }
         $query = sprintf('update %s set name = "%s" ,type = "%s" ,listorder = %d,default_value = "%s" ,required = %d where id = %d',
-        $tables["attribute"],addslashes($_POST["name"][$id]),$_POST["type"][$id],$listorder[$id],$default[$id],$required[$id],$id);
+        $tables["attribute"],addslashes($_POST["name"][$id]),$_POST["type"][$id],$_POST['listorder'][$id],sql_escape($_POST['default'][$id]),$_POST['required'][$id],$id);
         Sql_Query($query);
       }
     }
@@ -295,7 +295,7 @@ function warn() {
   warned = 1;
 }
 </script>
-<?=formStart()?>
+<?php echo formStart()?>
 <?php
 print $GLOBALS['I18N']->get('loadfrom')." ".PageLink2("defaults",$GLOBALS['I18N']->get('defaults')).'<br />';
 
