@@ -3,11 +3,11 @@ $lan = array(
 	"Deleting" => "Eliminando",
 	"Done" => "Listo",
 	"No template have been defined" => "No se ha definido
-	ning&uacute;na plantilla",
-	"Existing templates" => "Plantillas existentes",
+	ning&uacute;n patr&oacute;n",
+	"Existing templates" => "Patrones existentes",
 	"View" => "Ver",
 	"Edit" => "Editar",
   'delete' => 'Eliminar',
-	"Add new Template" => "A&ntilde;adir plantilla",
+	"Add new Template" => "A&ntilde;adir patr&oacute;n",
 );
 ?>
\ No newline at end of file
